==> Zonemaster-CLI-v1.0.3.tar.gz: Zonemaster-CLI-v1.0.3/README.md <==
Zonemaster CLI
==============
[![Build Status](https://travis-ci.org/dotse/zonemaster-engine.svg?branch=master)](https://travis-ci.org/dotse/zonemaster-engine)
[![CPAN version](https://badge.fury.io/pl/Zonemaster-CLI.svg)](https://metacpan.org/pod/Zonemaster::CLI)

### Purpose

This Git repository is one of the components of the Zonemaster software and contains the source for the Zonemaster CLI utility.

For an overview of the Zonemaster software, please see the
[Zonemaster repository](https://github.com/dotse/zonemaster).

## Prerequisite

Before you install the Zonemaster CLI utility, you need the
Zonemaster Engine test framework installed. Please see the
[Zonemaster Engine installation
instructions](https://github.com/dotse/zonemaster-engine/blob/master/docs/installation.md).

Installation
============

Installation instructions for the CLI
[installation](docs/installation.md) document.


### Configuration 

This repository does not need any specific configuration.

### Documentation

Other than the installation documentation, no specific documentation is needed.
The [using](https://github.com/dotse/zonemaster/blob/master/docs/using.md)
document provides an overview on how to use the CLI. 


### Participation

The core development team are people from IIS and Afnic. However, you
can submit code by forking this repository and create pull requests.

You can follow the project in these two mailinglists:

 * [zonemaster-users](http://lists.iis.se/cgi-bin/mailman/listinfo/zonemaster-users)
 * [zonemaster-devel](http://lists.iis.se/cgi-bin/mailman/listinfo/zonemaster-devel)

### Contact or Bug reporting 

For any contacts or bug reporting, please send a mail to
"contact@zonemaster.net".

License
=======

The software is released under the 2-clause BSD license. See separate LICENSE file.

==> Zonemaster-CLI-v1.1.1.tar.gz: Zonemaster-CLI-v1.1.1/README.md <==
Zonemaster CLI
==============
[![Build Status](https://travis-ci.org/dotse/zonemaster-engine.svg?branch=master)](https://travis-ci.org/dotse/zonemaster-engine)
[![CPAN version](https://badge.fury.io/pl/Zonemaster-CLI.svg)](https://metacpan.org/pod/Zonemaster::CLI)

### Purpose

This Git repository is one of the components of the Zonemaster software and contains the source for the Zonemaster CLI utility.

For an overview of the Zonemaster software, please see the
[Zonemaster repository](https://github.com/dotse/zonemaster).

## Prerequisite

Before you install the Zonemaster CLI utility, you need the
Zonemaster Engine test framework installed. Please see the
[Zonemaster Engine installation
instructions](https://github.com/dotse/zonemaster-engine/blob/master/docs/Installation.md).

Installation
============

Installation instructions for the CLI
[installation](docs/Installation.md) document.


### Configuration 

This repository does not need any specific configuration.

### Documentation

Other than the installation documentation, no specific documentation is needed.
The [using](https://github.com/dotse/zonemaster-cli/blob/master/USING.md)
document provides an overview on how to use the CLI. 


### Participation

The core development team are people from IIS and Afnic. However, you
can submit code by forking this repository and create pull requests.

You can follow the project in these two mailinglists:

 * [zonemaster-users](http://lists.iis.se/cgi-bin/mailman/listinfo/zonemaster-users)
 * [zonemaster-devel](http://lists.iis.se/cgi-bin/mailman/listinfo/zonemaster-devel)

### Contact or Bug reporting

For any contacts or bug reporting, please send a mail to
"contact@zonemaster.net".

License
=======

The software is released under the 2-clause BSD license. See separate LICENSE file.
